==> scanbot_sdk-1.1.0.tar.gz: ios/Classes/Extensions/SDK/Machine Codes/SBSDKUIMachineCodeScannerUIConfiguration.swift <==
//
//  SBSDKUIMachineCodeScannerUIConfiguration.swift
//  scanbot_sdk
//
//  Created by Zhenya Knizhnik on 26.08.19.
//

import Foundation
import ScanbotSDK

extension SBSDKUIMachineCodeScannerUIConfiguration {
    convenience init(from dictionary: [String: Any]) {
        self.init()
        if let hex = dictionary["topBarButtonsColor"] as? String {
            self.topBarButtonsColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["topBarBackgroundColor"] as? String {
            self.topBarBackgroundColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["cameraOverlayColor"] as? String {
            self.cameraOverlayColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["finderLineColor"] as? String {
            self.finderLineColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["finderTextHintColor"] as? String {
            self.finderTextHintColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["bottomButtonsInactiveColor"] as? String {
            self.bottomButtonsInactiveColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["bottomButtonsActiveColor"] as? String {
            self.bottomButtonsActiveColor = UIColor(hexString: hex)
        }
        
        if let cancelButtonHidden = dictionary["cancelButtonHidden"] as? Bool {
            self.isCancelButtonHidden = cancelButtonHidden
        }
        
        if let finderLineWidth = dictionary["finderLineWidth"] as? CGFloat {
            self.finderLineWidth = finderLineWidth
        }
        
        if let finderWidth = dictionary["finderWidth"] as? CGFloat {
            self.finderWidth = finderWidth
        }
        
        if let finderHeight = dictionary["finderHeight"] as? CGFloat {
            self.finderHeight = finderHeight
        }
        
        if let string = dictionary["orientationLockMode"] as? String {
            let allowedInterfaceOrientations = UIInterfaceOrientationMask(from: string)
            self.allowedInterfaceOrientations = allowedInterfaceOrientations
        }
    }
}

==> scanbot_sdk-2.0.1.tar.gz: ios/Classes/Extensions/SDK/Machine Codes/SBSDKUIMachineCodeScannerUIConfiguration.swift <==
//
//  SBSDKUIMachineCodeScannerUIConfiguration.swift
//  scanbot_sdk
//
//  Created by Zhenya Knizhnik on 26.08.19.
//

import Foundation
import ScanbotSDK

extension SBSDKUIMachineCodeScannerUIConfiguration {
    convenience init(from dictionary: [String: Any]) {
        self.init()
        if let hex = dictionary["topBarButtonsColor"] as? String {
            self.topBarButtonsColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["topBarBackgroundColor"] as? String {
            self.topBarBackgroundColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["cameraOverlayColor"] as? String {
            self.cameraOverlayColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["finderLineColor"] as? String {
            self.finderLineColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["finderTextHintColor"] as? String {
            self.finderTextHintColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["flashButtonInactiveColor"] as? String {
            self.flashButtonInactiveColor = UIColor(hexString: hex)
        }
        
        if let cancelButtonHidden = dictionary["cancelButtonHidden"] as? Bool {
            self.isCancelButtonHidden = cancelButtonHidden
        }
        
        if let finderLineWidth = dictionary["finderLineWidth"] as? CGFloat {
            self.finderLineWidth = finderLineWidth
        }
        
        if let aspectDict = dictionary["finderAspectRatio"] as? [String: Any],
            let aspectRatio = SBSDKAspectRatio(from: aspectDict) {
            self.finderAspectRatio = aspectRatio
        }
        
        if let string = dictionary["orientationLockMode"] as? String {
            let allowedInterfaceOrientations = UIInterfaceOrientationMask(from: string)
            self.allowedInterfaceOrientations = allowedInterfaceOrientations
        }
    }
}
